#!/usr/bin/perl -w
use strict;
use ExtUtils::MakeMaker;
use File::Spec;
use CTK;

use constant {
        PROJECT_NAME  => "NoRFC",
        PROJECT_NAMEL => "norfc",
    };

my $build_requires = {
        'CTK'                   => 2.03,
        'ExtUtils::MakeMaker'   => 6.60,
        'Test::More'            => 0.94,
    };

my $prereq_pm = {
        'CTK'                   => 2.03, # perl-CTK
        'Encode::Locale'        => 1.00, # perl-Encode-Locale
        'Text::CSV'             => 1.30, # perl-Text-CSV, libtext-csv-perl
        'YAML::LibYAML'         => 0.18, # perl-YAML-LibYAML
        'File::HomeDir'         => 1.00, # perl-File-HomeDir
    };

my $exefiles = [qw(
        bin/norfc
    )];

my $ctk = new CTK( project => PROJECT_NAME );
WriteMakefile(
    'NAME'              => PROJECT_NAME,
    'DISTNAME'          => PROJECT_NAMEL,
    'MIN_PERL_VERSION'  => 5.016001,
    'VERSION_FROM'      => 'lib/NoRFC.pm',
    'ABSTRACT_FROM'     => 'lib/NoRFC.pm',
    'BUILD_REQUIRES'    => $build_requires,
    'PREREQ_PM'         => $prereq_pm,
    'EXE_FILES'         => $exefiles,
    'AUTHOR'            => 'Serz Minus (Sergey Lepenkov) <minus@serzik.com>',
    'LICENSE'           => 'GPL',
    'META_MERGE'        => {
        resources => {
            homepage        => 'https://www.serzik.com',
            repository      => 'https://www.serzik.com:8008/misc/norfc',
            license         => 'http://opensource.org/licenses/gpl-license.php',
        },
    },
    macro => {
            PROJECT_NAME    => PROJECT_NAME,
            PROJECT_NAMEL   => PROJECT_NAMEL,
            PROJECT_CONFDIR => '$(DESTDIR)' . $ctk->root,
        },
    clean => {
            FILES => '$(INST_CONF) *.tmp norfc.db',
        },
);

1;

package MY;
use CTK::Util qw/dformat/;

sub postamble {
my $section = <<'MAKE_FRAG';
INST_CONF = blib$(DFSEP)conf

CRLF = $(ABSPERLRUNINST) -MCTK::Command -e crlf --

pure_all :: configured.tmp
[TAB]$(NOECHO) $(ECHO) "Configured."

# Configure
configured.tmp : conf$(DFSEP)$(PROJECT_NAMEL).conf $(INST_CONF)$(DFSEP).exists
[TAB]$(CP) conf$(DFSEP)$(PROJECT_NAMEL).conf $(INST_CONF)
[TAB]$(CRLF) $(INST_CONF)
[TAB]$(NOECHO) $(TOUCH) configured.tmp

# Creating directories
$(INST_CONF)$(DFSEP).exists :: Makefile.PL
[TAB]$(MKPATH) $(INST_CONF)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(INST_CONF)
[TAB]$(NOECHO) $(TOUCH) $(INST_CONF)$(DFSEP).exists

install :: installed.tmp
[TAB]$(NOECHO) $(ECHO) The $(PROJECT_NAME) project has been successfully installed.

installed.tmp : configured.tmp
[TAB]$(MKPATH) $(PROJECT_CONFDIR)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(PROJECT_CONFDIR)
[TAB]$(TEST_F) $(PROJECT_CONFDIR)$(DFSEP)$(PROJECT_NAMEL).conf && $(CP) $(INST_CONF)$(DFSEP)$(PROJECT_NAMEL).conf $(PROJECT_CONFDIR)$(DFSEP)$(PROJECT_NAMEL).conf.orig || $(CP) $(INST_CONF)$(DFSEP)$(PROJECT_NAMEL).conf $(PROJECT_CONFDIR)$(DFSEP)$(PROJECT_NAMEL).conf
[TAB]$(NOECHO) $(TOUCH) installed.tmp
MAKE_FRAG

return dformat($section, {
        TAB => "\t",
    });
}

1;

__END__
