#!/usr/bin/perl -w
#########################################################################
#
# Serz Minus (Sergey Lepenkov), <abalama@cpan.org>
#
# Copyright (C) 1998-2020 D&D Corporation. All Rights Reserved
#
# This is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.
#
# $Id: 03-store.t 131 2020-06-11 14:08:57Z minus $
#
#########################################################################
use Test::More tests => 9;
use NoRFC::Store;

# Create instance
my $store = new NoRFC::Store(
    file => "norfc_test.db.tmp",
    attributes => "RaiseError=0; PrintError=0; sqlite_unicode=1",
); #note(explain($store));
ok($store->status, "Create Store instance") or diag($store->error);
ok($store->ping, "Ping") or diag($store->error);

# Add new record #1
{
    ok($store->add(
        num     	=> "RFC-R0000000",
        pub     	=> time(),
        category	=> "Unknown",
        title 		=> "Test document",
    ), "Add new record 1") or diag($store->error);
}

# Get record data
my %info = ();
{
    %info = $store->get("RFC-R0000000");
    ok($info{id} && $store->status, "Get record data for RFC-R0000000") or diag($store->error);
}
#note(explain(\%info));

# Add new record #2
{
    ok($store->add(
        num     	=> "RFC-R0000001",
        pub     	=> time(),
        category	=> "Unknown",
        title 		=> "Test document 2",
    ), "Add new record 2") or diag($store->error);
}

# Update record
{
    ok($store->set(
        num     	=> "RFC-R0000000",
        pub     	=> time(),
        category	=> "Informational",
        title 		=> "Test document 1 - is updated",
    ), "Update record 1") or diag($store->error);
}

# Get all records
my @all = ();
{
    @all = $store->getall();
    ok(@all && $store->status, "Get all records") or diag($store->error);
}
#note(explain(\@all));

# Delete record
{
    ok($store->del($info{id}), "Delete record by id") or diag($store->error);
}

# Delete all records
{
    ok($store->truncate(), "Delete all records") or diag($store->error);
}

1;

__END__
